==> ejc-ztpcdc-impl-3.0.0-20230505.055326-10-sources.jar: com/ejianc/business/dc/bean/DcFiledistributeMenuEntity.java <==
package com.ejianc.business.dc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 文件中心目录菜单
 *
 * @author generator
 */
@TableName("dc_filedistribute_menu")
public class DcFiledistributeMenuEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "project_id")
    private Long projectId; // 项目ID
    @TableField(value = "project_code")
    private String projectCode; // 项目编码
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "code")
    private String code; // 编号
    @TableField(value = "name")
    private String name; // 名称
    @TableField(value = "attribute")
    private Long attribute; // 文件属性
    @TableField(value = "order_num")
    private Integer orderNum; // 顺序号
    @TableField(value = "menu_type")
    private Long menuType; // 菜单类型
    @TableField(value = "menu_type_code")
    private String menuTypeCode; // 菜单类型编号
    @TableField(value = "wkfl_code")
    private String wkflCode; // 工作流编号
    @TableField(value = "wkfl_name")
    private String wkflName; // 工作流名称
    @TableField(value = "online_id")
    private String onlineId; // 在线编辑模板id
    @TableField(value = "online_name")
    private String onlineName; // 在线编辑模板名称
    @TableField(value = "online_attachment")
    private String onlineAttachment; // 在线编辑模板附件
    @TableField(value = "create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value = "org_id")
    private Long orgId; // 所属项目组织id（公用类型为2时适用）
    @TableField(value = "org_code")
    private String orgCode; // 组织编码
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 所属组织
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 所属组织名称

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getAttribute() {
        return attribute;
    }

    public void setAttribute(Long attribute) {
        this.attribute = attribute;
    }

    public Integer getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(Integer orderNum) {
        this.orderNum = orderNum;
    }

    public Long getMenuType() {
        return menuType;
    }

    public void setMenuType(Long menuType) {
        this.menuType = menuType;
    }

    public String getMenuTypeCode() {
        return menuTypeCode;
    }

    public void setMenuTypeCode(String menuTypeCode) {
        this.menuTypeCode = menuTypeCode;
    }

    public String getWkflCode() {
        return wkflCode;
    }

    public void setWkflCode(String wkflCode) {
        this.wkflCode = wkflCode;
    }

    public String getWkflName() {
        return wkflName;
    }

    public void setWkflName(String wkflName) {
        this.wkflName = wkflName;
    }

    public String getOnlineId() {
        return onlineId;
    }

    public void setOnlineId(String onlineId) {
        this.onlineId = onlineId;
    }

    public String getOnlineName() {
        return onlineName;
    }

    public void setOnlineName(String onlineName) {
        this.onlineName = onlineName;
    }

    public String getOnlineAttachment() {
        return onlineAttachment;
    }

    public void setOnlineAttachment(String onlineAttachment) {
        this.onlineAttachment = onlineAttachment;
    }

    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

}

==> ejc-ztpcdc-impl-3.0.0-20250312.082320-383-sources.jar: com/ejianc/business/dc/bean/DcFiledistributeMenuEntity.java <==
package com.ejianc.business.dc.bean;

import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableName;
import com.ejianc.framework.skeleton.template.BaseEntity;

/**
 * 文件中心目录菜单
 *
 * @author generator
 */
@TableName("dc_filedistribute_menu")
public class DcFiledistributeMenuEntity extends BaseEntity {
    private static final long serialVersionUID = 1L;

    @TableField(value = "project_id")
    private Long projectId; // 项目ID
    @TableField(value = "project_code")
    private String projectCode; // 项目编码
    @TableField(value = "project_name")
    private String projectName; // 项目名称
    @TableField(value = "code")
    private String code; // 编号
    @TableField(value = "name")
    private String name; // 名称
    @TableField(value = "attribute")
    private Long attribute; // 文件属性
    @TableField(value = "order_num")
    private Integer orderNum; // 顺序号
    @TableField(value = "menu_type")
    private Long menuType; // 菜单类型
    @TableField(value = "menu_type_code")
    private String menuTypeCode; // 菜单类型编号
    @TableField(value = "filecode_rule_id")
    private Long filecodeRuleId; // 外部编码取号规则id
    @TableField(value = "filecode_rule_name")
    private String filecodeRuleName; // 外部编码取号规则名称
    @TableField(value = "internalcode_rule_id")
    private Long internalcodeRuleId; // 内部编码取号规则id
    @TableField(value = "internalcode_rule_name")
    private String internalcodeRuleName; // 内部编码取号规则名称
    @TableField(value = "wkfl_code")
    private Long wkflCode; // 工作流id
    @TableField(value = "wkfl_name")
    private String wkflName; // 工作流名称
    @TableField(value = "online_id")
    private Long onlineId; // 在线编辑模板id
    @TableField(value = "online_name")
    private String onlineName; // 在线编辑模板名称
    @TableField(value = "online_attachment")
    private String onlineAttachment; // 在线编辑模板附件
    @TableField(value = "create_dept_id")
    private Long createDeptId; // 创建部门id
    @TableField(value = "org_id")
    private Long orgId; // 所属项目组织id（公用类型为2时适用）
    @TableField(value = "org_code")
    private String orgCode; // 组织编码
    @TableField(value = "org_name")
    private String orgName; // 组织名称
    @TableField(value = "parent_org_id")
    private Long parentOrgId; // 所属组织
    @TableField(value = "parent_org_code")
    private String parentOrgCode; // 所属组织编码
    @TableField(value = "parent_org_name")
    private String parentOrgName; // 所属组织名称

    public Long getProjectId() {
        return projectId;
    }

    public void setProjectId(Long projectId) {
        this.projectId = projectId;
    }

    public String getProjectCode() {
        return projectCode;
    }

    public void setProjectCode(String projectCode) {
        this.projectCode = projectCode;
    }

    public String getProjectName() {
        return projectName;
    }

    public void setProjectName(String projectName) {
        this.projectName = projectName;
    }

    public String getCode() {
        return code;
    }

    public void setCode(String code) {
        this.code = code;
    }

    public String getName() {
        return name;
    }

    public void setName(String name) {
        this.name = name;
    }

    public Long getAttribute() {
        return attribute;
    }

    public void setAttribute(Long attribute) {
        this.attribute = attribute;
    }

    public Integer getOrderNum() {
        return orderNum;
    }

    public void setOrderNum(Integer orderNum) {
        this.orderNum = orderNum;
    }

    public Long getMenuType() {
        return menuType;
    }

    public void setMenuType(Long menuType) {
        this.menuType = menuType;
    }

    public String getMenuTypeCode() {
        return menuTypeCode;
    }

    public void setMenuTypeCode(String menuTypeCode) {
        this.menuTypeCode = menuTypeCode;
    }

    public Long getFilecodeRuleId() {
        return filecodeRuleId;
    }

    public void setFilecodeRuleId(Long filecodeRuleId) {
        this.filecodeRuleId = filecodeRuleId;
    }

    public String getFilecodeRuleName() {
        return filecodeRuleName;
    }

    public void setFilecodeRuleName(String filecodeRuleName) {
        this.filecodeRuleName = filecodeRuleName;
    }

    public Long getInternalcodeRuleId() {
        return internalcodeRuleId;
    }

    public void setInternalcodeRuleId(Long internalcodeRuleId) {
        this.internalcodeRuleId = internalcodeRuleId;
    }

    public String getInternalcodeRuleName() {
        return internalcodeRuleName;
    }

    public void setInternalcodeRuleName(String internalcodeRuleName) {
        this.internalcodeRuleName = internalcodeRuleName;
    }

    public Long getWkflCode() {
        return wkflCode;
    }

    public void setWkflCode(Long wkflCode) {
        this.wkflCode = wkflCode;
    }

    public String getWkflName() {
        return wkflName;
    }

    public void setWkflName(String wkflName) {
        this.wkflName = wkflName;
    }

    public Long getOnlineId() {
        return onlineId;
    }

    public void setOnlineId(Long onlineId) {
        this.onlineId = onlineId;
    }

    public String getOnlineName() {
        return onlineName;
    }

    public void setOnlineName(String onlineName) {
        this.onlineName = onlineName;
    }

    public String getOnlineAttachment() {
        return onlineAttachment;
    }

    public void setOnlineAttachment(String onlineAttachment) {
        this.onlineAttachment = onlineAttachment;
    }

    public Long getCreateDeptId() {
        return createDeptId;
    }

    public void setCreateDeptId(Long createDeptId) {
        this.createDeptId = createDeptId;
    }

    public Long getOrgId() {
        return orgId;
    }

    public void setOrgId(Long orgId) {
        this.orgId = orgId;
    }

    public String getOrgCode() {
        return orgCode;
    }

    public void setOrgCode(String orgCode) {
        this.orgCode = orgCode;
    }

    public String getOrgName() {
        return orgName;
    }

    public void setOrgName(String orgName) {
        this.orgName = orgName;
    }

    public Long getParentOrgId() {
        return parentOrgId;
    }

    public void setParentOrgId(Long parentOrgId) {
        this.parentOrgId = parentOrgId;
    }

    public String getParentOrgCode() {
        return parentOrgCode;
    }

    public void setParentOrgCode(String parentOrgCode) {
        this.parentOrgCode = parentOrgCode;
    }

    public String getParentOrgName() {
        return parentOrgName;
    }

    public void setParentOrgName(String parentOrgName) {
        this.parentOrgName = parentOrgName;
    }

}
